
const aws = require('aws-sdk');
const _ = require('lodash');

exports.AmazonRegistry = class {
    constructor(options) {
        this.Promise = options.promise || Promise;

        this._ecr    = new aws.ECR({
            accessKeyId: options.accessKeyId,
            secretAccessKey: options.secretAccessKey,
            region: options.region
        });
    }

    _refreshAuthorizationToken() {
        const tokenExpires = _.get(this, '_auth.expiresAt', new Date(0));

        if (new Date() > tokenExpires) {
            return new this.Promise((resovle, reject) => {
                this._ecr.getAuthorizationToken((err, data) => {
                    if (err) {
                        reject(err);
                    } else {
                      resovle(data);
                    }
                })
            })
                .then(data => data.authorizationData[0])
                .then(({ proxyEndpoint, authorizationToken, expiresAt }) => {
                    const domain = proxyEndpoint.substring('https://'.length);

                    const [username, password] =
                              new Buffer(authorizationToken, 'base64').toString().split(':');

                    this._auth = {
                        domain,
                        expiresAt,
                        credentials: {
                            username,
                            password
                        }
                    };
                });
        } else {
            return this.Promise.resolve();
        }
    }

    getCredentials() {
        return this._refreshAuthorizationToken()
            .then(() => this._auth.credentials);
    }

    getDomain() {
        return this._refreshAuthorizationToken()
            .then(() => this._auth.domain);
    }
};
