
const googleAuth = require('google-auto-auth');

exports.GoogleRegistry = class {

    constructor(options) {
        this.Promise = options.promise || Promise;

        if (options.keyfile) {
            const keyFileContent = JSON.parse(options.keyfile);

            this._projectId = keyFileContent.project_id;

            this._googleAuth = googleAuth({
                credentials: {
                    client_email: keyFileContent.client_email,
                    private_key: keyFileContent.private_key
                },
                scopes: ['https://www.googleapis.com/auth/devstorage.read_write']
            });
        } else {
            this._googleAuth = googleAuth({
                keyFilename: options.keyFilePath,
                scopes: ['https://www.googleapis.com/auth/devstorage.read_write']
            });
        }
    }

    getCredentials() {
        return new this.Promise((resolve, reject) => {
            this._googleAuth.getToken((err, token) => {
              if (err) {
                reject(err);
              } else {
                resolve(token)
              }
            })
        })
            .then((token) => {
                return {
                    username: 'oauth2accesstoken',
                    password: token
                };
            });
    }

    getDomain() {
        return this.Promise.resolve('gcr.io');
    }
};
